@@ -5,7 +5,7 @@ from models import Post
 
 
 class PostAdmin(admin.ModelAdmin):
-    list_display = ('headline', 'author', 'creation_date')
+    list_display = ['headline', 'author', 'creation_date']
 
     def save_model(self, request, obj, form, change):
         try:
@@ -14,4 +14,7 @@ class PostAdmin(admin.ModelAdmin):
             obj.author = request.user
         obj.save()
 
+class VisibilityPostAdminMixin(admin.ModelAdmin):
+    list_display = ['visibility',]
+
 admin.site.register(Post, PostAdmin)
