@@ -15,10 +15,19 @@ class AbstractPost(models.Model):
     def __unicode__(self):
         return self.headline
 
-
 class Post(AbstractPost):
     pass
 
+class VisibilityPostManagerMixin(models.Manager):
+    def get_visible(self):
+        return self.filter(visible=True)
+
+class VisibilityPostMixin(models.Model):
+    visible = models.BooleanField(default=True)
+
+    class Meta:
+        abstract = True
+
 class PositionPostMixin(models.Model):
     position = models.IntegerField()
 
@@ -27,8 +36,8 @@ class PositionPostMixin(models.Model):
         abstract = True
 
 class LinkPostMixin(models.Model):
-    link_url = models.URLField()
-    link_name = models.CharField(max_length=255)
+    link_url = models.URLField(blank=True)
+    link_name = models.CharField(max_length=255, blank=True)
 
     class Meta:
         abstract = True
